summary refs log tree commit diff
path: root/gnu/packages/base.scm
diff options
context:
space:
mode:
authorMarius Bakke <mbakke@fastmail.com>2017-10-22 22:11:19 +0200
committerMarius Bakke <mbakke@fastmail.com>2017-10-24 22:15:10 +0200
commit67d527e35e367c9e9e89ec01cda2ce32cabd2d89 (patch)
tree0f91970244af8e19602be64cb409b243ec08121e /gnu/packages/base.scm
parent2cce5fc59815f221f2671f91a7f44109f156367c (diff)
downloadguix-67d527e35e367c9e9e89ec01cda2ce32cabd2d89.tar.gz
gnu: glibc: Update to 2.26.
* gnu/packages/base.scm (glibc/linux): Update to 2.26.
[source](patches): Remove 'glibc-memchr-overflow-i686.patch',
'glibc-o-largefile.patch', 'glibc-vectorized-strcspn-guards.patch,
'glibc-CVE-2017-1000366-pt1.patch', 'glibc-CVE-2017-1000366-pt2.patch' and
'glibc-CVE-2017-1000366-pt3.patch'.
(glibc-2.25): New public variable.
Diffstat (limited to 'gnu/packages/base.scm')
-rw-r--r--gnu/packages/base.scm36
1 files changed, 26 insertions, 10 deletions
diff --git a/gnu/packages/base.scm b/gnu/packages/base.scm
index b7d60de589..f519e10350 100644
--- a/gnu/packages/base.scm
+++ b/gnu/packages/base.scm
@@ -508,14 +508,14 @@ store.")
 (define-public glibc/linux
   (package
    (name "glibc")
-   (version "2.25")
+   (version "2.26")
    (source (origin
             (method url-fetch)
             (uri (string-append "mirror://gnu/glibc/glibc-"
                                 version ".tar.xz"))
             (sha256
              (base32
-              "1813dzkgw6v8q8q1m4v96yfis7vjqc9pslqib6j9mrwh6fxxjyq6"))
+              "1ggnj1hzjym7sn93rbwydcqd562q73lsb7g7kd199g6j9j9hlkp5"))
             (snippet
              ;; Disable 'ldconfig' and /etc/ld.so.cache.  The latter is
              ;; required on LFS distros to avoid loading the distro's libc.so
@@ -526,13 +526,8 @@ store.")
             (modules '((guix build utils)))
             (patches (search-patches "glibc-ldd-x86_64.patch"
                                      "glibc-versioned-locpath.patch"
-                                     "glibc-o-largefile.patch"
-                                     "glibc-memchr-overflow-i686.patch"
-                                     "glibc-vectorized-strcspn-guards.patch"
                                      "glibc-CVE-2017-15670-15671.patch"
-                                     "glibc-CVE-2017-1000366-pt1.patch"
-                                     "glibc-CVE-2017-1000366-pt2.patch"
-                                     "glibc-CVE-2017-1000366-pt3.patch"))))
+                                     "glibc-o-largefile.patch"))))
    (build-system gnu-build-system)
 
    ;; Glibc's <limits.h> refers to <linux/limit.h>, for instance, so glibc
@@ -585,10 +580,10 @@ store.")
                                       "kernel-headers")
                            "/include")
 
             ;; This is the default for most architectures as of GNU libc 2.21,
             ;; but we specify it explicitly for clarity and consistency.  See
             ;; "kernel-features.h" in the GNU libc for details.
-            "--enable-kernel=2.6.32"
+            "--enable-kernel=3.2.0"
 
             ;; Use our Bash instead of /bin/sh.
             (string-append "BASH_SHELL="
@@ -816,6 +811,27 @@ GLIBC/HURD for a Hurd host"
 ;; Below are old libc versions, which we use mostly to build locale data in
 ;; the old format (which the new libc cannot cope with.)
 
+(define-public glibc-2.25
+  (package
+    (inherit glibc)
+    (version "2.25")
+    (source (origin
+              (inherit (package-source glibc))
+              (uri (string-append "mirror://gnu/glibc/glibc-"
+                                  version ".tar.xz"))
+              (sha256
+               (base32
+                "1813dzkgw6v8q8q1m4v96yfis7vjqc9pslqib6j9mrwh6fxxjyq6"))
+              (patches (search-patches "glibc-ldd-x86_64.patch"
+                                       "glibc-versioned-locpath.patch"
+                                       "glibc-o-largefile.patch"
+                                       "glibc-vectorized-strcspn-guards.patch"
+                                       "glibc-CVE-2015-5180.patch"
+                                       "glibc-CVE-2017-15670-15671.patch"
+                                       "glibc-CVE-2017-1000366-pt1.patch"
+                                       "glibc-CVE-2017-1000366-pt2.patch"
+                                       "glibc-CVE-2017-1000366-pt3.patch"))))))
+
 (define-public glibc-2.24
   (package
     (inherit glibc)
@@ -585,10 +580,10 @@ store.")
                            "/include")
 
-            ;; This is the default for most architectures as of GNU libc 2.21,
+            ;; This is the default for most architectures as of GNU libc 2.26,
             ;; but we specify it explicitly for clarity and consistency.  See
             ;; "kernel-features.h" in the GNU libc for details.